#
# spec file for package python-pylsp-rope
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pylsp-rope
Version:        0.1.17
Release:        1.1
Summary:        Extended refactoring capabilities for Python LSP Server using Rope
License:        MIT
URL:            https://github.com/python-rope/pylsp-rope
Source:         https://files.pythonhosted.org/packages/source/p/pylsp_rope/pylsp_rope-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module typing_extensions if %python-base <= 3.9}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-python-lsp-server
Requires:       python-rope
Requires:       (python-typing_extensions if python-base <= 3.9)
Suggests:       python-twine
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-lsp-server}
BuildRequires:  %{python_module rope}
BuildRequires:  %{python_module typing_extensions}
# /SECTION
%python_subpackages

%description
Extended refactoring capabilities for Python LSP Server using Rope.

This is a plugin for Python LSP Server.

%prep
%autosetup -p1 -n pylsp_rope-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%{python_expand rm -rf %{buildroot}%{$python_sitelib}/test
%fdupes %{buildroot}%{$python_sitelib}
}

%check
%pytest

%files %{python_files}
%doc AUTHORS.txt README.md
%license LICENSE
%{python_sitelib}/pylsp_rope
%{python_sitelib}/pylsp_rope-%{version}*-info

%changelog
* Thu May 15 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.1.17
  * fix(inline): do not offer changeless inline refactor,
    backed by test by @YotamAlon in #30
- Adjust upstream source name in spec file
- Use Python 3.11 on SLE-15 by default
* Wed Mar 20 2024 Matej Cepl <mcepl@cepl.eu>
- Update to 0.1.16:
  - Implement lsp_rename()
* Tue Mar 12 2024 Matej Cepl <mcepl@cepl.eu>
- Update to 0.1.15 (we can do released tarballs again):
  - Change WorkspaceEdit to use documentChanges
  - Add files missing from the source packages needed for running
    tests
* Mon Mar 11 2024 mcepl@cepl.eu
- Because of gh#python-rope/pylsp-rope#25 we have to switch to
  git checkout again.
- Update to version 0.1.13+git.1710166725.0bcf4d3:
  * Add fallback import for TypeGuard
  * Hardcode executeCommand to use WorkspaceEditWithChanges
  * Blacken
  * Implement rope_changeset_to_workspace_edit(workspace_edit_format) argument
  * Add TypeGuard for distinguishing between WorkspaceEditWithChanges and WorkspaceEditWithDocumentChanges
  * Fix type hints to use List instead of list
  * Remove SimpleWorkspaceEdit, replaced with WorkspaceEditWithChanges
  * Implement convert_workspace_edit_document_changes_to_changes()
  * Refine the type annotation for rope_changeset_to_workspace_edit()
* Mon Mar 11 2024 Matej Cepl <mcepl@cepl.eu>
- Update to 0.1.13:
  - Revert "remove non-standard title in executeCommand"
  - Remove pkg_resources, replace with importlib.resources
  - Drop Python 3.7, add Python 3.12
- Update to 0.1.12:
  - remove non-standard title in executeCommand
  - Use List, not list, this syntax isn't supported yet in our oldest supported version
  - fix type hint issue in CommandRefactorUseFunction
  - Update python-lsp/cookiecutter-pylsp-plugin link
* Tue Jan 17 2023 Matej Cepl <mcepl@suse.com>
- Update to 0.1.11:
  - Move codeAction Command* to pylsp_rope.refactoring
  - Implement generate.{GenerateVariable(),GenerateClass(),get_code_actions(),GenerateFunction()}.
* Wed Oct  5 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v0.1.10
  * Bump version
  * Update README.md
  * Implement introduce parameter refactoring
  * Update python-publish.yml
  * Update run-test.yml
  * Update python-publish.yml
  * Add Python 3.10 to github actions test runner
* Sat Jul 16 2022 Matej Cepl <mcepl@suse.com>
- Update to 0.1.9:
  - Implement introduce parameter refactoring
* Sat Dec 18 2021 Matej Cepl <mcepl@suse.com>
- Upgrade to 0.1.8:
  - Add refactor extract method/variable including similar statements
    variant
  - Add refactor extract global method/variable variant
* Tue Nov 23 2021 Matej Cepl <mcepl@suse.com>
- Update to 0.1.7:
  - pylsp-rope now work on unsaved buffers. This support is
    currently experimental.
  - New Refactoring:
  - Implement local to field refactoring
  - Implement organize import code action
* Tue Oct 12 2021 Matej Cepl <mcepl@suse.com>
- Update to 0.1.6:
  - Fixed issue with missing typing-extensions dependency
  - Add use functions refactoring
  - Internal rewrites
  - Add type annotation for many things
  - Improve error handling during executeCommand()
* Tue Oct  5 2021 Matej Cepl <mcepl@suse.com>
- Update to 0.1.4:
  - Add method to method object refactoring
  - Supress all exceptions when determining codeActions
* Mon Oct  4 2021 Matej Cepl <mcepl@suse.com>
- Back to the tarballed release, 0.1.3.:
  - Fix #4. arguments must be list, not object
* Mon Oct  4 2021 mcepl@cepl.eu
- Update to version 0.1.2+git.1633327768.9245130:
  * Add python_requires clause to setup.cfg
  * Black
  * Read from pkg_resources instead of the filesystem
  * Fix #2. Use functools.lru_cache() instead of functools.cache()
- Remove functools-cache.patch as it has been upstreamed.
* Sun Oct  3 2021 mcepl@cepl.eu
- Update to version 0.1.2+git.1633266737.1e4a677:
  * Bump version
  * Fix CodeAction command response
  * Bump version
  * Always re-validate project on get_project()
  * Update README.md
  * Change package name to pylsp-rope
  * Add rope itself to list of dependencies :)
  * Update README.md
- Add functools-cache.patch making the package compatible with
  Python < 3.9 (gh#python-rope/pylsp-rope#2)
* Sun Oct  3 2021 mcepl@cepl.eu
- Update to version 0.0.0+git.1633239046.8355444:
  * Point to python-rope organisation repository
  * Rename command prefix to pylsp_rope
  * Implement pylsp_commands()
  * Use keyword parameters when calling executeCommand()
  * Implement rope_changeset_to_workspace_changeset() using lsp_diff()
  * Implement lsp_diff()
  * Add CONTRIBUTING.md
  * Update README.md
  * Add Features section in README.md
  * Update README.md
